#!/bin/bash

## Create minimal developement environment for NEMO
###################################################

## Optional arguments (developer ID, 'repo' to replicate the layout of the whole repository)

dir='NEMO_dev'; repo='0'; root='/NEMO'
url='http://forge.ipsl.jussieu.fr/nemo/svn'

rel=$( svn ls $url/NEMO/releases      | grep ^r[0-9] | tail -1 | tr -d / )
ver=$( svn ls $url/NEMO/releases/$rel                | tail -1 | tr -d / )

year=$( date +%Y )

while (( $# )); do
    [ "$1" == 'repo' ] && { dir='NEMO_repo' && repo='1' && root='/'; shift; }
    id=$1
    shift
done

[ -d $dir ] && { echo $dir 'already exists => QUIT'; exit 2; }

## Copy of the repository with empty root directories
echo 'Download a void working copy of' $root "from the repository ('svn co --depth empty ...')"
svn co --depth empty http://forge.ipsl.jussieu.fr/nemo/svn/$root $dir
echo

## Switch to developer role if ID is provided
if [[ -n "$id" && -f ~/.ssh/id_rsa.pub ]]; then
    echo 'Switch to developer role by relocating the URL scheme from HTTP to SVN+SSH'
    echo "('svn sw --relocate http://... svn+ssh://...')"
    ssh-copy-id -i ~/.ssh/id_rsa.pub $id@forge.ipsl.jussieu.fr 2> /dev/null
    svn sw --relocate $url svn+ssh://$id@forge.ipsl.jussieu.fr/ipsl/forge/projets/nemo/svn $dir
    echo
fi

## If requested by 'repo',
if [ "$repo" == '1' ]; then
    echo "With 'repo' arg, create a lightweight copy of the repository"
    echo 'for the developement of the sources defined as "externals"'

    for item in utils/build/{arch,makenemo,mk} utils/tools \
                vendors/{AGRIF/dev,FCM,IOIPSL}              ; do
        echo '¤' $item
        svn up -q --parents $dir/$item
    done

    dir+=/'NEMO'
    echo
fi

## Get the 1st level tree under 'branches' and 'releases'
echo "Get empty folders under /NEMO/branches ('svn up --depth empty ...'):"

for item in branches releases; do
    svn up -q --parents --depth immediates $dir/$item
done

echo

## Download trunk and last release
echo "Full download of 2 main branches ('svn up'): trunk and last stable"
echo '¤ /NEMO/trunk'
svn up -q           $dir/trunk

echo "¤ /NEMO/releases/$rel/$ver"
svn up -q --parents $dir/releases/$rel/$ver

exit 0
